declare module "axios-progress-bar";

interface MenuItem {
  path?: string;
  label: string;
  iconName?: string;
  children?: MenuItem[];
}

/** 分页数据 */
type MultiplePageData<T> = {
  pageCount?: number;
  pageNumber?: number;
  pageSize?: number;
  totalCount: number;
  result: T[];
};

interface LoginModel {
  loginName: string;
  password: string;
}

/** 登录结果 */
type LoginResult = {
  accessToken: string;
  name: string;
  role: string;
  schoolId: number;
  schoolName: string;
  sessionId: string;
};

/** 用户信息 */
type SystemUserInfo = {
  /** 科目代码集合 */
  courseCodes: string[];
  /** 科目名称 */
  courseNames: string[];
  createTime: string;
  /** 启用/禁用 */
  enable: boolean;
  /** 用户ID */
  id: number;
  /** 登录名 */
  loginName: string;
  /** 姓名 */
  name: string;
  /** 角色ID */
  roleId: number;
  /** 学校ID */
  schoolId: number;
  /** 学校名称 */
  schoolName: string;
  updateTime: string;
};

interface BaseMutPageQuery {
  pageNumber: number;
  pageSize: number;
}

/** 查询学校列表参数 */
interface FetchSchoolListQuery extends BaseMutPageQuery {
  /** 学校名称 */
  name?: string;
}

interface BaseSchoolInfo {
  /** 学校编码 */
  code?: string;
  /** 负责人 */
  contacts: string;
  id?: number;
  /** 学校名称 */
  name: string;
  /** 区域 */
  region: string;
  /** 联系方式 */
  telephone: string;
  /** 启用/禁用 */
  enable: boolean;
}

/** 学校列表信息 */
interface SchoolListInfo extends Required<BaseSchoolInfo> {
  createTime: string;
  creatorId: number;
  /** 二维码 */
  qrCode: string;
  updateTime: string;
  updaterId: number;
}

/** 查询用户列表参数 */
interface FetchUserListQuery extends BaseMutPageQuery {
  /** 用户名称 */
  loginName?: string;
  /** 用户角色 */
  role?: "SUPER_ADMIN" | "SCHOOL_ADMIN" | "SECTION_LEADER";
  /** 学校ID */
  schoolId?: string;
}

interface BaseUserInfo {
  /** 学校ID */
  schoolId: string;
  /** 启用/禁用 */
  enable?: boolean;
  /** 用户ID */
  id?: number;
  /** 登录名 */
  loginName: string;
  /** 姓名 */
  name: string;
  /** 角色ID */
  roleId: string;
}

/** 用户信息 */
interface UserInfo extends Required<BaseUserInfo> {
  /** 科目代码集合 */
  courseCodes: string[];
  /** 科目名称 */
  courseNames: string[];
  createTime: string;
  /** 学校名称 */
  schoolName: string;
  updateTime: string;
}

type EditUserInfo = Omit<BaseUserInfo, "roleId"> & {
  /** 用户角色 */
  role?: "SUPER_ADMIN" | "SCHOOL_ADMIN" | "SECTION_LEADER";
  /** 用户密码 */
  passwd?: string;
  /** 科目代码集合 */
  course: string;
};

interface FetchExamListQuery extends BaseMutPageQuery {
  /** 考试名称 */
  name?: string;
  /** 学校ID */
  schoolId?: string;
}

interface BaseExamInfo {
  /** 考试状态,可用值:EDIT,FINISH,CLOSE */
  examStatus?: string;
  /** 考试ID */
  id?: number;
  /** 考试名称 */
  name?: string;
  /** 学校ID */
  schoolId?: string;
}

/** 考试列表信息 */

interface ExamListInfo extends Required<BaseExamInfo> {
  /** 考试编码 */
  code: string;
  createTime: string;
  /** 科目数量 */
  paperCount: number;
  updateTime: string;
}

/** 科目查询参数 */
interface FetchSubjectsListQuery extends BaseMutPageQuery {
  /** 科目代码 */
  courseCode: string;
  courseName: string;
  /** 考试id */
  examId: string;
  /** 	分组状态 */
  groupFinish?: boolean;
  /** 学校id */
  schoolId: string;
  /** 总分截止值 */
  totalScoreMax: string;
  /** 总分起始值 */
  totalScoreMin: string;
}

/** 科目列表信息 */
interface SubjectsListInfo {
  /** 科目代码 */
  courseCode: string;
  /** 科目ID */
  courseId: number;
  /** 科目名称 */
  courseName: string;
  createTime: string;
  /** 考试ID */
  examId: number;
  /** 考试名称 */
  examName: string;
  /** 分组数量 */
  groupCount: number;
  /** 分组是否完成 */
  groupFinish: boolean;
  id: number;
  /** 学校ID */
  schoolId: number;
  /** 试卷结构是否提交 */
  structFinish: boolean;
  /** 主观题总分 */
  subjectiveScore: number;
  /** 试卷总分 */
  totalScore: number;
  updateTime: string;
}
